## API Reference Manual

The API reference manual is generated directly from documentation and declarations in the source code, and is thus often much more verbose than necessary, because many little-used yet often-duplicated methods are listed for each class.
Still, the reference for a given component does provide a comprehensive listing of all attributes and methods, inherited or otherwise, which is can be difficult to obtain from the source code directly.

[Annotate](annotate)

[App](app)

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 2

modules
```
